@@ -38,7 +38,16 @@ import logging
 from pathlib import Path
 import sys
 from types import ModuleType
-from typing import Any, Collection, Iterable, Iterator, BinaryIO, List, Union
+from typing import (
+    Any,
+    BinaryIO,
+    Collection,
+    Iterable,
+    Iterator,
+    List,
+    Optional,
+    Union,
+)
 import socket
 
 import serial  # type: ignore
@@ -49,10 +58,11 @@ from pw_console import PwConsoleEmbed
 from pw_console.pyserial_wrapper import SerialWithLogging
 
 from pw_log.proto import log_pb2
-from pw_tokenizer import tokens
+from pw_rpc.console_tools.console import ClientInfo, flattened_rpc_completions
+from pw_rpc import callback_client
 from pw_tokenizer.database import LoadTokenDatabases
 from pw_tokenizer.detokenize import Detokenizer, detokenize_base64
-from pw_rpc.console_tools.console import ClientInfo, flattened_rpc_completions
+from pw_tokenizer import tokens
 
 from pw_hdlc.rpc import HdlcRpcClient, default_channels
 
@@ -98,6 +108,9 @@ def _parse_args():
                         nargs="+",
                         action=LoadTokenDatabases,
                         help="Path to tokenizer database csv file(s).")
+    parser.add_argument('--config-file',
+                        type=Path,
+                        help='Path to a pw_console yaml config file.')
     parser.add_argument('--proto-globs',
                         nargs='+',
                         help='glob pattern for .proto files')
@@ -111,7 +124,8 @@ def _expand_globs(globs: Iterable[str]) -> Iterator[Path]:
 
 
 def _start_ipython_terminal(client: HdlcRpcClient,
-                            serial_debug: bool = False) -> None:
+                            serial_debug: bool = False,
+                            config_file_path: Optional[Path] = None) -> None:
     """Starts an interactive IPython terminal with preset variables."""
     local_variables = dict(
         client=client,
@@ -155,6 +169,7 @@ def _start_ipython_terminal(client: HdlcRpcClient,
         loggers=log_windows,
         repl_startup_message=welcome_message,
         help_text=__doc__,
+        config_file_path=config_file_path,
     )
     interactive_console.hide_windows('Host Logs')
     interactive_console.add_sentence_completer(completions)
@@ -196,7 +211,8 @@ def console(device: str,
             socket_addr: str,
             logfile: str,
             output: Any,
-            serial_debug: bool = False) -> int:
+            serial_debug: bool = False,
+            config_file: Optional[Path] = None) -> int:
     """Starts an interactive RPC console for HDLC."""
     # argparse.FileType doesn't correctly handle '-' for binary files.
     if output is sys.stdout:
@@ -249,11 +265,18 @@ def console(device: str,
             _LOG.exception('Failed to initialize socket at %s', socket_addr)
             return 1
 
+    callback_client_impl = callback_client.Impl(
+        default_unary_timeout_s=5.0,
+        default_stream_timeout_s=None,
+    )
     _start_ipython_terminal(
-        HdlcRpcClient(
-            read, protos, default_channels(write),
-            lambda data: detokenize_and_write_to_output(
-                data, output, detokenizer)), serial_debug)
+        HdlcRpcClient(read,
+                      protos,
+                      default_channels(write),
+                      lambda data: detokenize_and_write_to_output(
+                          data, output, detokenizer),
+                      client_impl=callback_client_impl), serial_debug,
+        config_file)
     return 0
 
 
