@@ -95,12 +95,12 @@ def gn_host_build(ctx: PresubmitContext):
 @filter_paths(endswith=_BUILD_EXTENSIONS)
 def gn_quick_build_check(ctx: PresubmitContext):
     """Checks the state of the GN build by running gn gen and gn check."""
-    build.gn_gen(ctx.root, ctx.output_dir, pw_rpc_USE_GLOBAL_MUTEX=True)
+    build.gn_gen(ctx.root, ctx.output_dir)
 
 
 @filter_paths(endswith=_BUILD_EXTENSIONS)
 def gn_full_build_check(ctx: PresubmitContext):
-    build.gn_gen(ctx.root, ctx.output_dir, pw_rpc_USE_GLOBAL_MUTEX=True)
+    build.gn_gen(ctx.root, ctx.output_dir)
     build.ninja(ctx.output_dir, *_at_all_optimization_levels('stm32f429i'),
                 *_at_all_optimization_levels(f'host_{_HOST_COMPILER}'),
                 'python.tests', 'python.lint', 'docs', 'fuzzers',
@@ -315,8 +315,8 @@ _MODULES_THAT_BUILD_WITH_BAZEL = [
     '//pw_multisink/...',
     '//pw_polyfill/...',
     '//pw_preprocessor/...',
-    '//pw_protobuf_compiler/...',
     '//pw_protobuf/...',
+    '//pw_protobuf_compiler/...',
     '//pw_random/...',
     '//pw_result/...',
     '//pw_rpc/...',
@@ -336,6 +336,7 @@ _MODULES_THAT_BUILD_WITH_BAZEL = [
     '//pw_thread_stl/...',
     '//pw_tool/...',
     '//pw_toolchain/...',
+    '//pw_transfer/...',
     '//pw_unit_test/...',
     '//pw_varint/...',
     '//pw_web_ui/...',
@@ -751,6 +752,7 @@ def renode_check(ctx: PresubmitContext):
 #
 
 OTHER_CHECKS = (
+    cpp_checks.all_sanitizers(),
     # Build that attempts to duplicate the build OSS-Fuzz does. Currently
     # failing.
     oss_fuzz_build,
